@@ -353,6 +353,7 @@
 #define HAVE_PPOLL 1
 #define HAVE_PREAD 1
 #define HAVE_PWRITE 1
+#define HAVE_QSORT_R 1
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_ROUND 1
@@ -416,6 +417,7 @@
 #define HAVE_BUILTIN___BUILTIN_TRAP 1
 #define HAVE_BUILTIN___BUILTIN_EXPECT 1
 #define USE___BUILTIN_MUL_OVERFLOW_LONG_LONG 1
+#define HAVE_GNU_QSORT_R 1
 #define ATAN2_INF_C99 1
 #define HAVE_CLOCK_GETRES 1
 #define HAVE_LIBRT 1
