@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.3.") or
-    raise "ruby lib version (3.3.7) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.3.9) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.3.0/aarch64-netbsd")
@@ -21,8 +21,8 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "3"
-  CONFIG["TEENY"] = "7"
-  CONFIG["PATCHLEVEL"] = "123"
+  CONFIG["TEENY"] = "9"
+  CONFIG["PATCHLEVEL"] = "170"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/pkg")
@@ -30,7 +30,7 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)33"
   CONFIG["RUBY_SO_NAME"] = "ruby33"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.3.7.pc"
+  CONFIG["ruby_pc"] = "ruby-3.3.9.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--enable-shared' '--enable-install-static-library' '--without-git' '--disable-rjit' '--enable-yjit' '--disable-dtrace' '--program-suffix=33' '--with-soname=ruby33' '--with-ruby-version=3.3.0' '--with-ruby-pc=ruby-3.3.7.pc' '--enable-pthread' '--prefix=/usr/pkg' '--build=aarch64--netbsd' '--host=aarch64--netbsd' '--mandir=/usr/pkg/man' 'build_alias=aarch64--netbsd' 'host_alias=aarch64--netbsd' 'CC=gcc' 'CXX=c++' 'CFLAGS=-O2 -pthread -I/usr/pkg/include -I/usr/include' 'LDFLAGS=-Wl,-zrelro -L/usr/pkg/lib -L/usr/lib -Wl,-R/usr/lib -Wl,-R/usr/pkg/lib -pthread' 'LIBS=' 'CPPFLAGS=-I/usr/pkg/include -I/usr/include' 'CXXFLAGS=-O2 -pthread -I/usr/pkg/include -I/usr/include'"
+  CONFIG["configure_args"] = " '--enable-shared' '--enable-install-static-library' '--without-git' '--disable-rjit' '--enable-yjit' '--disable-dtrace' '--program-suffix=33' '--with-soname=ruby33' '--with-ruby-version=3.3.0' '--with-ruby-pc=ruby-3.3.9.pc' '--enable-pthread' '--prefix=/usr/pkg' '--build=aarch64--netbsd' '--host=aarch64--netbsd' '--mandir=/usr/pkg/man' 'build_alias=aarch64--netbsd' 'host_alias=aarch64--netbsd' 'CC=gcc' 'CXX=c++' 'CFLAGS=-O2 -pthread -I/usr/pkg/include -I/usr/include' 'LDFLAGS=-Wl,-zrelro -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/lib -Wl,-R/usr/lib -pthread' 'LIBS=' 'CPPFLAGS=-I/usr/pkg/include -I/usr/include' 'CXXFLAGS=-O2 -pthread -I/usr/pkg/include -I/usr/include'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -139,7 +139,7 @@ module RbConfig
   CONFIG["CCDLFLAGS"] = "-fPIC"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = ""
-  CONFIG["DLDFLAGS"] = "-Wl,-zrelro -L/usr/pkg/lib -L/usr/lib -Wl,-R/usr/lib -Wl,-R/usr/pkg/lib -pthread -Wl,--compress-debug-sections=zlib"
+  CONFIG["DLDFLAGS"] = "-Wl,-zrelro -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/lib -Wl,-R/usr/lib -pthread -Wl,--compress-debug-sections=zlib"
   CONFIG["ALLOCA"] = ""
   CONFIG["EGREP"] = "/usr/bin/egrep"
   CONFIG["GREP"] = "/usr/bin/grep"
@@ -182,7 +182,7 @@ module RbConfig
   CONFIG["CXXFLAGS"] = "-O2 -pthread -I/usr/pkg/include -I/usr/include"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-I/usr/pkg/include -I/usr/include $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -Wl,-zrelro -L/usr/pkg/lib -L/usr/lib -Wl,-R/usr/lib -Wl,-R/usr/pkg/lib -pthread -Wl,-export-dynamic -Wl,--no-as-needed"
+  CONFIG["LDFLAGS"] = "-L. -Wl,-zrelro -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/lib -Wl,-R/usr/lib -pthread -Wl,-export-dynamic -Wl,--no-as-needed"
   CONFIG["CFLAGS"] = "-O2 -pthread -I/usr/pkg/include -I/usr/include -fPIC -pipe"
   CONFIG["STRIP"] = "strip -S -x"
   CONFIG["RANLIB"] = "ranlib"
